/****************************************************************************
** Meta object code from reading C++ file 'keychain_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qtkeychain/qtkeychain/keychain_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keychain_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QKeychain10JobPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QKeychain::JobPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN9QKeychain10JobPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QKeychain::JobPrivate",
        "kwalletWalletFound",
        "",
        "QDBusPendingCallWatcher*",
        "watcher",
        "kwalletFinished",
        "kwalletOpenFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'kwalletWalletFound'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'kwalletFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'kwalletOpenFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JobPrivate, qt_meta_tag_ZN9QKeychain10JobPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QKeychain::JobPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain10JobPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain10JobPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QKeychain10JobPrivateE_t>.metaTypes,
    nullptr
} };

void QKeychain::JobPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->kwalletWalletFound((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 1: _t->kwalletFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 2: _t->kwalletOpenFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *QKeychain::JobPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QKeychain::JobPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain10JobPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QKeychain::JobPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QKeychain::ReadPasswordJobPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QKeychain::ReadPasswordJobPrivate",
        "kwalletOpenFinished",
        "",
        "QDBusPendingCallWatcher*",
        "watcher",
        "kwalletEntryTypeFinished",
        "kwalletFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'kwalletOpenFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'kwalletEntryTypeFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'kwalletFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadPasswordJobPrivate, qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QKeychain::ReadPasswordJobPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<JobPrivate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>.metaTypes,
    nullptr
} };

void QKeychain::ReadPasswordJobPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadPasswordJobPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->kwalletOpenFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 1: _t->kwalletEntryTypeFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 2: _t->kwalletFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *QKeychain::ReadPasswordJobPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QKeychain::ReadPasswordJobPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain22ReadPasswordJobPrivateE_t>.strings))
        return static_cast<void*>(this);
    return JobPrivate::qt_metacast(_clname);
}

int QKeychain::ReadPasswordJobPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JobPrivate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QKeychain::WritePasswordJobPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QKeychain::WritePasswordJobPrivate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WritePasswordJobPrivate, qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QKeychain::WritePasswordJobPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<JobPrivate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>.metaTypes,
    nullptr
} };

void QKeychain::WritePasswordJobPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WritePasswordJobPrivate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QKeychain::WritePasswordJobPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QKeychain::WritePasswordJobPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain23WritePasswordJobPrivateE_t>.strings))
        return static_cast<void*>(this);
    return JobPrivate::qt_metacast(_clname);
}

int QKeychain::WritePasswordJobPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JobPrivate::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QKeychain::DeletePasswordJobPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QKeychain::DeletePasswordJobPrivate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeletePasswordJobPrivate, qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QKeychain::DeletePasswordJobPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<JobPrivate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>.metaTypes,
    nullptr
} };

void QKeychain::DeletePasswordJobPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeletePasswordJobPrivate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QKeychain::DeletePasswordJobPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QKeychain::DeletePasswordJobPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain24DeletePasswordJobPrivateE_t>.strings))
        return static_cast<void*>(this);
    return JobPrivate::qt_metacast(_clname);
}

int QKeychain::DeletePasswordJobPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JobPrivate::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9QKeychain11JobExecutorE_t {};
} // unnamed namespace

template <> constexpr inline auto QKeychain::JobExecutor::qt_create_metaobjectdata<qt_meta_tag_ZN9QKeychain11JobExecutorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QKeychain::JobExecutor",
        "jobFinished",
        "",
        "QKeychain::Job*",
        "jobDestroyed",
        "object"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'jobFinished'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'jobDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JobExecutor, qt_meta_tag_ZN9QKeychain11JobExecutorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QKeychain::JobExecutor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain11JobExecutorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain11JobExecutorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QKeychain11JobExecutorE_t>.metaTypes,
    nullptr
} };

void QKeychain::JobExecutor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobExecutor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->jobFinished((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 1: _t->jobDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QKeychain::Job* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *QKeychain::JobExecutor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QKeychain::JobExecutor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QKeychain11JobExecutorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QKeychain::JobExecutor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
